@@ -32,11 +32,10 @@
 #include <QPointF>
 #include <QTimer>
 #include <QKeyEvent>
-
-#include <KStandardDirs>
+#include <QDir>
 #include <KConfig>
-#include <KComponentData>
 #include <kgsound.h>
+#include <QStandardPaths>
 
 Game::Game(PlayerSettings* playerSettings)
 {
@@ -46,11 +45,11 @@ Game::Game(PlayerSettings* playerSettings)
     setSoundsEnabled(Settings::sounds());
     m_wilhelmScream = Settings::useWilhelmScream();
     
-    m_soundPutBomb = new KgSound(KStandardDirs::locate("appdata", "sounds/putbomb.wav"));
-    m_soundExplode = new KgSound(KStandardDirs::locate("appdata", "sounds/explode.wav"));
-    m_soundBonus = new KgSound(KStandardDirs::locate("appdata", "sounds/wow.wav"));
-    m_soundFalling = new KgSound(KStandardDirs::locate("appdata", "sounds/deepfall.wav"));
-    m_soundDie = new KgSound(KStandardDirs::locate("appdata", "sounds/die.wav"));
+    m_soundPutBomb = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, "sounds/putbomb.wav"));
+    m_soundExplode = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, "sounds/explode.wav"));
+    m_soundBonus = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, "sounds/wow.wav"));
+    m_soundFalling = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, "sounds/deepfall.wav"));
+    m_soundDie = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, "sounds/die.wav"));
     
     m_arena = 0;
     m_randomArenaModeArenaList.clear();
@@ -64,9 +63,9 @@ Game::Game(PlayerSettings* playerSettings)
         {
             Player* player = new Player(qreal(Granatier::CellSize * (-0.5)),qreal(Granatier::CellSize * 0.5), strPlayerIDs[i], playerSettings, m_arena);
             m_players.append(player);
-            connect(player, SIGNAL(dying()), this, SLOT(playerDeath()));
-            connect(player, SIGNAL(falling()), this, SLOT(playerFalling()));
-            connect(player, SIGNAL(resurrectBonusTaken()), this, SLOT(resurrectBonusTaken()));
+            connect(player, &Player::dying, this, &Game::playerDeath);
+            connect(player, &Player::falling, this, &Game::playerFalling);
+            connect(player, &Player::resurrectBonusTaken, this, &Game::resurrectBonusTaken);
         }
     }
     
@@ -97,11 +96,17 @@ void Game::init()
     {
         if(m_randomArenaModeArenaList.isEmpty())
         {
-            QStringList arenasAvailable;
             m_randomArenaModeArenaList = Settings::self()->randomArenaModeArenaList();
 
-            KGlobal::dirs()->addResourceType("arenaselector", "data", KGlobal::mainComponent().componentName() + "/arenas/");
-            KGlobal::dirs()->findAllResources("arenaselector", "*.desktop", KStandardDirs::Recursive, arenasAvailable);
+            QStringList arenasAvailable;
+            const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "arenas", QStandardPaths::LocateDirectory);
+            Q_FOREACH (const QString& dir, dirs) {
+            const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+                Q_FOREACH (const QString& file, fileNames) {
+                    arenasAvailable.append(dir + '/' + file);
+                }
+            }
+
 
             QStringList::Iterator i = m_randomArenaModeArenaList.begin();
             while(i != m_randomArenaModeArenaList.end())
@@ -131,18 +136,18 @@ void Game::init()
         {
             nIndex = m_randomArenaModeArenaList.count() - 1;
         }
-        filePath = KStandardDirs::locate("appdata", "arenas/" + m_randomArenaModeArenaList.at(nIndex));
+        filePath = m_randomArenaModeArenaList.at(nIndex);
         m_randomArenaModeArenaList.removeAt(nIndex);
     }
     else
     {
-        filePath = KStandardDirs::locate("appdata", Settings::self()->arena());
+        filePath = QStandardPaths::locate(QStandardPaths::DataLocation, Settings::self()->arena());
     }
     
     if(!QFile::exists(filePath))
     {
         Settings::self()->useDefaults(true);
-        filePath = KStandardDirs::locate("appdata", Settings::self()->arena());
+        filePath = QStandardPaths::locate(QStandardPaths::DataLocation, Settings::self()->arena());
         Settings::self()->useDefaults(false);
     }
     
@@ -150,8 +155,8 @@ void Game::init()
     KConfigGroup group = arenaConfig.group("Arena");
     QString arenaFileName = group.readEntry("FileName");
     
-    QFile arenaXmlFile(KStandardDirs::locate("appdata", QString("arenas/%1").arg(arenaFileName)));
-    //QFile arenaXmlFile(KStandardDirs::locate("appdata", "arenas/granatier.xml"));
+    QFile arenaXmlFile(QStandardPaths::locate(QStandardPaths::DataLocation, QString("arenas/%1").arg(arenaFileName)));
+    //QFile arenaXmlFile(QStandardPaths::locate(QStandardPaths::DataLocation, "arenas/granatier.xml"));
     QXmlInputSource source(&arenaXmlFile);
     // Create the XML file reader
     QXmlSimpleReader reader;
@@ -179,18 +184,18 @@ void Game::init()
     // Start the Game timer
     m_timer = new QTimer(this);
     m_timer->setInterval(int(1000 / Granatier::FPS));
-    connect(m_timer, SIGNAL(timeout()), this, SLOT(update()));
+    connect(m_timer, &QTimer::timeout, this, &Game::update);
     m_timer->start();
     m_state = RUNNING;
     
     m_roundTimer  = new QTimer(this);
     m_roundTimer->setInterval(1000);
-    connect(m_roundTimer, SIGNAL(timeout()), this, SLOT(decrementRemainingRoundTime()));
+    connect(m_roundTimer, &QTimer::timeout, this, &Game::decrementRemainingRoundTime);
     m_roundTimer->start();
     
     m_setRoundFinishedTimer  = new QTimer(this);
     m_setRoundFinishedTimer->setSingleShot(true);
-    connect(m_setRoundFinishedTimer, SIGNAL(timeout()), this, SLOT(setRoundFinished()));
+    connect(m_setRoundFinishedTimer, &QTimer::timeout, this, &Game::setRoundFinished);
     
     // Init the characters coordinates on the Arena
     for (int i = 0; i < m_players.size(); i++)
@@ -428,7 +433,7 @@ void Game::setSoundsEnabled(bool p_enabled)
 {
     m_soundEnabled = p_enabled;
     Settings::setSounds(p_enabled);
-    Settings::self()->writeConfig();
+    Settings::self()->save();
 }
 
 void Game::initCharactersPosition()
@@ -575,7 +580,7 @@ void Game::decrementRemainingRoundTime()
             Bomb* bomb = new Bomb((nCol + 0.5) * Granatier::CellSize, (nRow + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 1000);    // time in ms
             bomb->setBombPower((qrand()/1.0)/RAND_MAX * 2 + 1);
             emit bombCreated(bomb);
-            connect(bomb, SIGNAL(bombDetonated(Bomb*)), this, SLOT(bombDetonated()));
+            connect(bomb, &Bomb::bombDetonated, this, &Game::bombDetonated);
             m_bombs.append(bomb);
             if(m_remainingTime > -100 && m_roundTimer->interval() > 150)
             {
@@ -705,8 +710,8 @@ void Game::createBomb(Player* player, qreal x, qreal y, bool newBomb, int throwD
     Bomb* bomb = new Bomb((col + 0.5) * Granatier::CellSize, (row + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 2500);    // time in ms
     bomb->setBombPower(player->getBombPower());
     emit bombCreated(bomb);
-    connect(bomb, SIGNAL(bombDetonated(Bomb*)), this, SLOT(bombDetonated()));
-    connect(bomb, SIGNAL(releaseBombArmory()), player, SLOT(slot_refillBombArmory()));
+    connect(bomb, &Bomb::bombDetonated, this, &Game::bombDetonated);
+    connect(bomb, &Bomb::releaseBombArmory, player, &Player::slot_refillBombArmory);
     m_bombs.append(bomb);
     player->decrementBombArmory();
     
